[clutter] docs: Fix a typo in the BoxLayout:homogeneous description



commit 38e983b8e9e2b433ef6ba930dca9096958bae697
Author: Emmanuele Bassi <ebassi gnome org>
Date:   Fri Aug 21 12:11:05 2015 +0100

    docs: Fix a typo in the BoxLayout:homogeneous description
    
    https://bugzilla.gnome.org/show_bug.cgi?id=753895

 clutter/clutter-box-layout.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/clutter/clutter-box-layout.c b/clutter/clutter-box-layout.c
index 12ce1e3..ba4eee0 100644
--- a/clutter/clutter-box-layout.c
+++ b/clutter/clutter-box-layout.c
@@ -1371,7 +1371,7 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    * ClutterBoxLayout:homogeneous:
    *
    * Whether the #ClutterBoxLayout should arrange its children
    * homogeneously, i.e. all childs get the same size
    *
    * Since: 1.4
    */
@@ -1379,7 +1379,7 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
     g_param_spec_boolean ("homogeneous",
                           P_("Homogeneous"),
                           P_("Whether the layout should be homogeneous, "
-                             "i.e. all childs get the same size"),
+                             "i.e. all children get the same size"),
                           FALSE,
                           CLUTTER_PARAM_READWRITE);
 
@@ -1371,7 +1371,7 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
    *
    * Whether the #ClutterBoxLayout should arrange its children
-   * homogeneously, i.e. all childs get the same size
+   * homogeneously, i.e. all children get the same size
    *
    * Since: 1.4


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]